#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import Interface, implementer
from zope.schema.fieldproperty import FieldProperty

from onf_website.shared.casestudy import IWfCaseStudy
from onf_website.shared.service import IWfService
from onf_website.shared.view.skin.interfaces import IONFViewItemsPortletNewsRendererSettings
from onf_website.skin.public import owl_carousel_init, owl_navigation
from pyams_content.shared.view.portlet.interfaces import IViewItemsPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_sequence.reference import get_reference_target
from pyams_skin.layer import IPyAMSLayer, IPyAMSUserLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config

from onf_website import _


@factory_config(provided=IONFViewItemsPortletNewsRendererSettings)
@implementer(IONFViewItemsPortletNewsRendererSettings)
class ONFViewItemsPortletNewsRendererSettings(Persistent, Contained):
    """View items portlet renderer settings"""

    list_reference = FieldProperty(IONFViewItemsPortletNewsRendererSettings['list_reference'])
    link_label = FieldProperty(IONFViewItemsPortletNewsRendererSettings['link_label'])

    def get_target(self):
        if self.list_reference is not None:
            return get_reference_target(self.list_reference)


@adapter_config(name='ONF::view.actus',
                context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/actus.pt', layer=IPyAMSUserLayer)
class ONFViewItemsPortletNewsRenderer(PortletRenderer):
    """View items portlet renderer"""

    label = _("ONF: news and folders")
    weight = 1

    settings_interface = IONFViewItemsPortletNewsRendererSettings
    resources = (owl_carousel_init, owl_navigation)


@adapter_config(name='ONF::view.actus-tight',
                context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/actus-tight.pt', layer=IPyAMSUserLayer)
class ONFTicghtViewItemsPortletNewsRenderer(PortletRenderer):
    """View items portlet tight renderer"""

    label = _("ONF: news and folder (tight version)")
    weight = 2

    settings_interface = IONFViewItemsPortletNewsRendererSettings


@adapter_config(name='ONF::view.related',
                context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/related.pt', layer=IPyAMSUserLayer)
class ONFViewRelatedItemsPortletRenderer(PortletRenderer):
    """Related items portlet renderer"""

    label = _("ONF: related contents")
    weight = 3

    resources = (owl_carousel_init, owl_navigation)


@adapter_config(name='ONF::view.partners',
                context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/partners-logos.pt', layer=IPyAMSUserLayer)
class ONFViewPartnersLogosPortletRenderer(PortletRenderer):
    """Partners logos portlet renderer"""

    label = _("ONF: services partners logos")
    weight = 4

    @property
    def logos(self):
        settings = self.settings
        for content in settings.get_items(self.request):
            if not (IWfService.providedBy(content) or IWfCaseStudy.providedBy(content)):
                continue
            for logo in content.get_targets():
                if not logo.image:
                    continue
                yield content, logo
